# tkSDLImg

Display an image inside your tkinter application using SDL for fast rendering.
This also allows for frequent updates to allow video playbacks, animation, etc.

## Installation

```sh
pip install tkSDLImg
```

## Usage

A usage example can be found in the modules `_main` function.
